.. SPDX-FileCopyrightText: 2021-2024 SanderTheDragon <sanderthedragon@zoho.com>
..
.. SPDX-License-Identifier: CC-BY-SA-4.0

###################################
SanderTheDragon's Sphinx Extensions
###################################
These are some `Sphinx <https://www.sphinx-doc.org>`_ extensions I wrote, feel free to use them.

- `Code Block Buttons <https://sanderthedragon.gitlab.io/sphinx-extensions/codeblockbuttons.html>`_ adds copy and view buttons to code blocks.
- `Extra Lexers <https://sanderthedragon.gitlab.io/sphinx-extensions/extralexers.html>`_ adds extra lexers to pygments currently only LLVM JSON.
- `Inline Code Highlight <https://sanderthedragon.gitlab.io/sphinx-extensions/inlinecodehighlight.html>`_ adds custom roles to be able to highlight inline code.
- `Mapped Link Role <https://sanderthedragon.gitlab.io/sphinx-extensions/mappedlinkrole.html>`_ adds custom roles which can be mapped to links.

************
Installation
************
The extensions can be installed with **pip**.

.. code-block:: sh

   pip install sanderthedragon-sphinxext

***********
Source Code
***********
The source code is hosted on `GitLab <https://gitlab.com/SanderTheDragon/sphinx-extensions>`_.

*********
Changelog
*********
Changelog is available `here <https://sanderthedragon.gitlab.io/sphinx-extensions/changelog.html>`_.

*******
License
*******
These documents are licensed under `CC-BY-SA-4.0 <https://spdx.org/licenses/CC-BY-SA-4.0.html>`_.
Code and examples are licensed under `MIT <https://spdx.org/licenses/MIT.html>`_.
Other files, like configuration files are licensed under `CC0-1.0 <https://spdx.org/licenses/CC0-1.0.html>`_.
